# eminus

Main source code directory.

| File            | Description |
| :-------------: | :---------: |
| atoms.py        | Atoms class definition |
| config.py       | Consolidated configuration module |
| data.py         | Atom specific data |
| dft.py          | DFT routines |
| domains.py      | Domain generation |
| energies.py     | Energy object and calculation |
| gga.py          | Functions needed for GGAs and meta-GGAs |
| gth.py          | GTH pseudopotential functions |
| localizer.py    | Localization routines |
| logger.py       | Logging configuration |
| minimizer.py    | Minimization algorithms |
| occupations.py  | Determine occupations |
| operators.py    | Plane wave basis-set dependent operators |
| orbitals.py     | Orbital generation workflows |
| potentials.py   | Miscellaneous (pseudo-)potentials |
| scf.py          | SCF class definition |
| tools.py        | Tools to calculate physical properties |
| units.py        | Constants and unit conversion functions |
| utils.py        | Linear algebra and random utilities |
| version.py      | Package versions file |
